==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/sche_submenu.php <==
<?
//==============================================================
// Program Name		: 塼륵֥˥塼
// File Name		: sche_submenu.php
//--------------------------------------------------------------
// Date             : 2002/02/13
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");
require("sche_commonfunction.inc");		// 塼붦̴ؿ

define("PARENT_PG", "sche_main.php");


//==============================================================
// Function Name    : Print_QuickInput
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Print_QuickInput()
{
	global $PHP_SELF, $JJ_USER_ID, $time_array;
	global $hiduke;
	
	// JavaScript
	?>
	<script language="JavaScript">
		function submit_form(form) {
			if (form.from_time.selectedIndex > form.to_time.selectedIndex) {
				alert('ֻ꤬Ǥ');
				return;
			}
			form.submit();
		}
	</script>
	<?

	// դʬ
	Explode_Date($hiduke, $year, $month, $day);
	
	printf("<form action=\"%s\" method=\"post\" target=\"_parent\">\n", PARENT_PG);
	print("<table cellpadding=\"0\" cellspacing=\"0\" border=\"1\">\n");
	print("<tr>\n");
	printf("<td align=\"center\" class=\"color00\"><font color=\"%s\"><b>åϿ</b></font></td>\n", FONT_COLOR_1);
	print("</tr>\n");
	
	printf("<tr><td bgcolor=\"%s\">\n", BG_COLOR_5);
	print("<table border=\"0\" cellpadding=\"2\" cellspacing=\"3\">\n");
	
	// 
	print("<tr><td><br>\n");
	print("<select name=\"month\">\n");
	for ($i=1; $i<=12; $i++) {
		if ($month == $i) {
			printf("<option value=\"%s\" selected>%s</option>\n", $i, $i);
		} else {
			printf("<option value=\"%s\">%s</option>\n", $i, $i);
		}
	}
	print("</select>\n");
	print("<select name=\"day\">\n");
	for ($i=1; $i<=31; $i++) {
		if ($day == $i) {
			printf("<option value=\"%s\" selected>%s</option>\n", $i, $i);
		} else {
			printf("<option value=\"%s\">%s</option>\n", $i, $i);
		}
	}
	print("</select></td></tr>\n");
	
	// 
	print("<tr><td><br>\n");
	print("<select name=\"from_time\">\n");
	for ($i=0; $i<count($time_array) - 1; $i++) {
		$hm = explode(":", $time_array[$i]);
		printf("<option value=\"%s\">%d:%02d</option>\n", $time_array[$i], $hm[0], $hm[1]);
	}
	print("</select>\n");
	print(" <select name=\"to_time\">\n");
	for ($i=1; $i<count($time_array); $i++) {
		$hm = explode(":", $time_array[$i]);
		printf("<option value=\"%s\">%d:%02d</option>\n", $time_array[$i], $hm[0], $hm[1]);
	}
	print("</select></td></tr>\n");
	
	// 
	print("<tr><td><br>\n");
	print("<input type=\"text\" size=\"20\" maxlength=\"255\" name=\"data\" value=\"\">\n");
	print("</td></tr>\n");
	
	// /
	$db = new DB_Test;
	$str = "SELECT init_publicdata FROM sche_option";
	$str .= sprintf(" WHERE member_id = '%s'", $JJ_USER_ID);
	$db->query($str);
	$check_str = "";
	if ($db->nf() > 0) {
		$db->next_record();
		if ($db->f("init_publicdata") == 1)
			$check_str = " checked";
	}
	$db->close();
	print("<tr><td>\n");
	printf("<input type=\"checkbox\" name=\"public_data\" value=\"1\"%s>ͽ",
		$check_str);
	print("</td></tr>\n");

	//ܥ
	print("<tr><td align=\"center\">\n");
	print("<input type=\"hidden\" name=\"action\" value=\"quick_add\">\n");
	printf("<input type=\"hidden\" name=\"year\" value=\"%d\">\n", $year);
	print("<input type=\"button\" value=\"Ͽ\" onclick=\"submit_form(this.form);\">\n");
	print("</td></tr>\n");
	print("</table></td></tr></table></form>\n");
}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

if (!isset($sel))
	$sel = 0;
if (!isset($mst))
	$mst = "";

include("common_printheader.inc");

print("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\n");
print("<tr><td align=\"center\">\n");
Print_Callendar(PARENT_PG, $mst, $sel, "_parent");
print("</td></tr>\n");
print("<tr><td height=\"10\">&nbsp;</td></tr>\n");
print("<tr><td align=\"center\">\n");
Print_QuickInput();
print("</td></tr>\n");
print("</table>\n");

include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/sche_submenu.php <==
<?
//==============================================================
// Program Name		: 塼륵֥˥塼
// File Name		: sche_submenu.php
//--------------------------------------------------------------
// Date             : 2002/02/13
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("sche_commonfunction.inc");		// 塼붦̴ؿ

define("PARENT_PG", "sche_main.php");


//==============================================================
// Function Name    : Print_QuickInput
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Print_QuickInput()
{
	global $PHP_SELF, $JJ_USER_ID, $time_array;
	global $hiduke;
	
	// JavaScript
	?>
	<script language="JavaScript">
		function submit_form(form) {
			if (form.from_time.selectedIndex > form.to_time.selectedIndex) {
				alert('ֻ꤬Ǥ');
				return;
			}
			form.submit();
		}
	</script>
	<?

	// դʬ
	Explode_Date($hiduke, $year, $month, $day);
	
	printf("<form action=\"%s\" method=\"post\" target=\"_parent\">\n", PARENT_PG);
	print("<table cellpadding=\"0\" cellspacing=\"0\" border=\"1\">\n");
	print("<tr>\n");
	printf("<td align=\"center\" class=\"color00\"><font color=\"%s\"><b>åϿ</b></font></td>\n", FONT_COLOR_1);
	print("</tr>\n");
	
	printf("<tr><td bgcolor=\"%s\">\n", BG_COLOR_5);
	print("<table border=\"0\" cellpadding=\"2\" cellspacing=\"3\">\n");
	
	// 
	print("<tr><td><br>\n");
	print("<select name=\"month\">\n");
	for ($i=1; $i<=12; $i++) {
		if ($month == $i) {
			printf("<option value=\"%s\" selected>%s</option>\n", $i, $i);
		} else {
			printf("<option value=\"%s\">%s</option>\n", $i, $i);
		}
	}
	print("</select>\n");
	print("<select name=\"day\">\n");
	for ($i=1; $i<=31; $i++) {
		if ($day == $i) {
			printf("<option value=\"%s\" selected>%s</option>\n", $i, $i);
		} else {
			printf("<option value=\"%s\">%s</option>\n", $i, $i);
		}
	}
	print("</select></td></tr>\n");
	
	// 
	print("<tr><td><br>\n");
	print("<select name=\"from_time\">\n");
	for ($i=0; $i<count($time_array) - 1; $i++) {
		$hm = explode(":", $time_array[$i]);
		printf("<option value=\"%s\">%d:%02d</option>\n", $time_array[$i], $hm[0], $hm[1]);
	}
	print("</select>\n");
	print(" <select name=\"to_time\">\n");
	for ($i=1; $i<count($time_array); $i++) {
		$hm = explode(":", $time_array[$i]);
		printf("<option value=\"%s\">%d:%02d</option>\n", $time_array[$i], $hm[0], $hm[1]);
	}
	print("</select></td></tr>\n");
	
	// 
	print("<tr><td><br>\n");
	print("<input type=\"text\" size=\"20\" maxlength=\"255\" name=\"data\" value=\"\">\n");
	print("</td></tr>\n");
	
	// /
	$db = new DB_Test;
	$str = "SELECT init_publicdata FROM sche_option";
	$str .= sprintf(" WHERE member_id = '%s'", $JJ_USER_ID);
	$db->query($str);
	$check_str = "";
	if ($db->nf() > 0) {
		$db->next_record();
		if ($db->f("init_publicdata") == 1)
			$check_str = " checked";
	}
	$db->close();
	print("<tr><td>\n");
	printf("<input type=\"checkbox\" name=\"public_data\" value=\"1\"%s>ͽ",
		$check_str);
	print("</td></tr>\n");

	//ܥ
	print("<tr><td align=\"center\">\n");
	print("<input type=\"hidden\" name=\"action\" value=\"quick_add\">\n");
	printf("<input type=\"hidden\" name=\"year\" value=\"%d\">\n", $year);
	print("<input type=\"button\" value=\"Ͽ\" onclick=\"submit_form(this.form);\">\n");
	print("</td></tr>\n");
	print("</table></td></tr></table></form>\n");
}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

if (!isset($sel))
	$sel = 0;
if (!isset($mst))
	$mst = "";

include("common_printheader.inc");

print("<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\n");
print("<tr><td align=\"center\">\n");
Print_Callendar(PARENT_PG, $mst, $sel, "_parent");
print("</td></tr>\n");
print("<tr><td height=\"10\">&nbsp;</td></tr>\n");
print("<tr><td align=\"center\">\n");
Print_QuickInput();
print("</td></tr>\n");
print("</table>\n");

include("common_printfooter.inc");

?>
